# kagenda

kagenda is a tool for giving me an overview of my day. Right now, it implements
a weather forecast and a listing of calendar events for the next 24h. It is
expected that I'll be able to look at my calendar to see where or who is going,
so it really only focuses on an overview that serves as a reminder.